@@ -1,5 +1,5 @@
-"""Top-level package for FTL Events."""
+"""Top-level package for Ansible Events."""
 
 __author__ = """Ben Thomasson"""
 __email__ = 'ben.thomasson@gmail.com'
-__version__ = '0.1.9'
+__version__ = '0.1.1'
