@@ -1,17 +1,21 @@
 from __future__ import annotations
 
-from typing import NamedTuple, Union, List, Any, Dict
+from typing import NamedTuple, Union, List, Any, Dict, Optional
 import ansible_events.condition_types as ct
 
 import asyncio
 import multiprocessing as mp
 
+class EventSourceFilter(NamedTuple):
+
+    filter_name: str
+    filter_args: dict
 
 class EventSource(NamedTuple):
     name: str
     source_name: str
     source_args: dict
-    transform: Union[str, None]
+    source_filters: List[EventSourceFilter]
 
 
 class Action(NamedTuple):
@@ -20,13 +24,15 @@ class Action(NamedTuple):
 
 
 class Condition(NamedTuple):
-    value: ct.Condition
+    when: str
+    value: List[ct.Condition]
 
 
 class Rule(NamedTuple):
     name: str
     condition: Condition
     action: Action
+    enabled: bool
 
 
 class RuleSet(NamedTuple):
